@@ -400,6 +400,8 @@ struct parse_key {
 	{"KEY_FRAMEFORWARD", 0x1b5},
 	{"KEY_CONTEXT_MENU", 0x1b6},
 	{"KEY_MEDIA_REPEAT", 0x1b7},
+	{"KEY_10CHANNELSUP", 0x1b8},
+	{"KEY_10CHANNELSDOWN", 0x1b9},
 	{"KEY_DEL_EOL", 0x1c0},
 	{"KEY_DEL_EOS", 0x1c1},
 	{"KEY_INS_LINE", 0x1c2},
@@ -448,6 +450,51 @@ struct parse_key {
 	{"KEY_NUMERIC_STAR", 0x20a},
 	{"KEY_NUMERIC_POUND", 0x20b},
 	{"KEY_CAMERA_FOCUS", 0x210},
+	{"KEY_WPS_BUTTON", 0x211},
+	{"KEY_TOUCHPAD_TOGGLE", 0x212},
+	{"KEY_TOUCHPAD_ON", 0x213},
+	{"KEY_TOUCHPAD_OFF", 0x214},
+	{"BTN_TRIGGER_HAPPY", 0x2c0},
+	{"BTN_TRIGGER_HAPPY1", 0x2c0},
+	{"BTN_TRIGGER_HAPPY2", 0x2c1},
+	{"BTN_TRIGGER_HAPPY3", 0x2c2},
+	{"BTN_TRIGGER_HAPPY4", 0x2c3},
+	{"BTN_TRIGGER_HAPPY5", 0x2c4},
+	{"BTN_TRIGGER_HAPPY6", 0x2c5},
+	{"BTN_TRIGGER_HAPPY7", 0x2c6},
+	{"BTN_TRIGGER_HAPPY8", 0x2c7},
+	{"BTN_TRIGGER_HAPPY9", 0x2c8},
+	{"BTN_TRIGGER_HAPPY10", 0x2c9},
+	{"BTN_TRIGGER_HAPPY11", 0x2ca},
+	{"BTN_TRIGGER_HAPPY12", 0x2cb},
+	{"BTN_TRIGGER_HAPPY13", 0x2cc},
+	{"BTN_TRIGGER_HAPPY14", 0x2cd},
+	{"BTN_TRIGGER_HAPPY15", 0x2ce},
+	{"BTN_TRIGGER_HAPPY16", 0x2cf},
+	{"BTN_TRIGGER_HAPPY17", 0x2d0},
+	{"BTN_TRIGGER_HAPPY18", 0x2d1},
+	{"BTN_TRIGGER_HAPPY19", 0x2d2},
+	{"BTN_TRIGGER_HAPPY20", 0x2d3},
+	{"BTN_TRIGGER_HAPPY21", 0x2d4},
+	{"BTN_TRIGGER_HAPPY22", 0x2d5},
+	{"BTN_TRIGGER_HAPPY23", 0x2d6},
+	{"BTN_TRIGGER_HAPPY24", 0x2d7},
+	{"BTN_TRIGGER_HAPPY25", 0x2d8},
+	{"BTN_TRIGGER_HAPPY26", 0x2d9},
+	{"BTN_TRIGGER_HAPPY27", 0x2da},
+	{"BTN_TRIGGER_HAPPY28", 0x2db},
+	{"BTN_TRIGGER_HAPPY29", 0x2dc},
+	{"BTN_TRIGGER_HAPPY30", 0x2dd},
+	{"BTN_TRIGGER_HAPPY31", 0x2de},
+	{"BTN_TRIGGER_HAPPY32", 0x2df},
+	{"BTN_TRIGGER_HAPPY33", 0x2e0},
+	{"BTN_TRIGGER_HAPPY34", 0x2e1},
+	{"BTN_TRIGGER_HAPPY35", 0x2e2},
+	{"BTN_TRIGGER_HAPPY36", 0x2e3},
+	{"BTN_TRIGGER_HAPPY37", 0x2e4},
+	{"BTN_TRIGGER_HAPPY38", 0x2e5},
+	{"BTN_TRIGGER_HAPPY39", 0x2e6},
+	{"BTN_TRIGGER_HAPPY40", 0x2e7},
 	{"KEY_MAX", 0x2ff},
 	{ NULL, 0}
 };
